View source: R/user_get_estimates.R
| get_estimates | R Documentation |
Gathers model and estimate information for an RSTr model object, exported as a long table. Estimate rates and their respective credible intervals are displayed by default in rates per 100,000.
get_estimates(RSTr_obj, rates_per = 1e+05, standardized = TRUE)
RSTr_obj |
An |
rates_per |
The desired scaling for estimate rates. |
standardized |
If |
A long table containing region/group/time period names, estimates, credible intervals, relative precisions, and the associated event/population counts.
std_pop <- c(113154, 100640, 95799)
data_min <- lapply(miheart, \(x) x[1:2, 1:3, 1:3])
adj_min <- list(2, 1)
on.exit(unlink(file.path(tempdir(), "test"), recursive = TRUE), add = TRUE)
mod_mst <- mstcar("test", data_min, adj_min, tempdir(), show_plots = FALSE, verbose = FALSE)
estimates_table <- get_estimates(mod_mst)
mod_mst <- age_standardize(mod_mst, std_pop, "35-64")
estimates_table_as <- get_estimates(mod_mst)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.