minsample: Samples Generated for Michigan data

minsampleR Documentation

Samples Generated for Michigan data

Description

A 4-dimensional array of samples generated by the MSTCAR Gibbs sampler for use in testing and examples

Usage

minsample

Format

'minsample' a small sample dataset to be used in examples, generated by an MSTCAR model with two regions, three age groups, and three time periods.


RSTr documentation built on Jan. 31, 2026, 9:07 a.m.