View source: R/user_suppress_estimates.R
| suppress_estimates | R Documentation |
Generates suppressed estimates for an RSTr model object with a given relative precision and population/event threshold.
suppress_estimates(RSTr_obj, threshold = 0, type = c("population", "event"))
RSTr_obj |
An |
threshold |
The population/event suppression threshold. |
type |
Determines whether suppression threshold is based on population counts or event counts. |
While the threshold argument is optional, population/event thresholds are necessary for non-restricted models. Population/event thresholds should only be omitted for restricted CAR models, such as the RCAR.
An RSTr model object with suppressed estimates.
std_pop <- c(113154, 100640, 95799)
data_min <- lapply(miheart, \(x) x[1:2, 1:3, 1:3])
adj_min <- list(2, 1)
on.exit(unlink(file.path(tempdir(), "test"), recursive = TRUE), add = TRUE)
mod_mst <- mstcar("test", data_min, adj_min, tempdir(), show_plots = FALSE, verbose = FALSE)
mod_mst <- suppress_estimates(mod_mst, threshold = 1000, type = "population")
estimates_table <- get_estimates(mod_mst)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.