| minsample | R Documentation |
A 4-dimensional array of samples generated by the MSTCAR Gibbs sampler for use in testing and examples
minsample
'minsample' a small sample dataset to be used in examples, generated by an MSTCAR model with two regions, three age groups, and three time periods.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.