Learn R Programming

RSTr (version 1.1.4)

suppress_estimates: Suppress estimates based on reliability criteria

Description

Generates suppressed estimates for an RSTr model object with a given relative precision and population/event threshold.

Usage

suppress_estimates(RSTr_obj, threshold = 0, type = c("population", "event"))

Value

An RSTr model object with suppressed estimates.

Arguments

RSTr_obj

An RSTr model object.

threshold

The population/event suppression threshold.

type

Determines whether suppression threshold is based on population counts or event counts.

Details

While the threshold argument is optional, population/event thresholds are necessary for non-restricted models. Population/event thresholds should only be omitted for restricted CAR models, such as the RCAR.

Examples

Run this code
std_pop <- c(113154, 100640, 95799)
data_min <- lapply(miheart, \(x) x[1:2, 1:3, 1:3])
adj_min <- list(2, 1)
on.exit(unlink(file.path(tempdir(), "test"), recursive = TRUE), add = TRUE)
mod_mst <- mstcar("test", data_min, adj_min, tempdir(), show_plots = FALSE, verbose = FALSE)
mod_mst <- suppress_estimates(mod_mst, threshold = 1000, type = "population")
estimates_table <- get_estimates(mod_mst)

Run the code above in your browser using DataLab